@@ -3,7 +3,7 @@ import errno
 import logging
 from pytest import fixture
 from stat import ST_MODE
-from mock import patch
+from unittest.mock import patch
 
 from kiwi.utils.sync import DataSync
 
@@ -71,3 +71,6 @@ class TestDataSync:
         effect.errno = errno.ENOTSUP
         mock_getxattr.side_effect = effect
         assert self.sync.target_supports_extended_attributes() is False
+        effect = NotImplemented
+        mock_getxattr.side_effect = effect
+        assert self.sync.target_supports_extended_attributes() is True
